summaryrefslogtreecommitdiff
path: root/gnu
diff options
context:
space:
mode:
authorSharlatan Hellseher <sharlatanus@gmail.com>2026-01-17 23:01:07 +0000
committerAndreas Enge <andreas@enge.fr>2026-02-07 12:28:26 +0100
commite524d03142e3ae5ddc56e8a2570e0b5dc544ef6e (patch)
tree01f3cf7ad7633c2067f1ad311d4cb32dd9c78520 /gnu
parentddf12c910ce2aa03b2f0ac467e4f1fa26f82d6a3 (diff)
gnu: python-pytest-xdist: Skip 2 more tests.
* gnu/packages/check.scm (python-pytest-xdist): [arguments] <test-flags>: Reworks skipped tests, add 2 more. [native-inputs]: Remove python-wheel. [synopsis, description]: Replace py.test with pytest. Change-Id: Ie454f68dfe2c18819f1ea2e3b41b2d100270ec12
Diffstat (limited to 'gnu')
-rw-r--r--gnu/packages/check.scm27
1 files changed, 20 insertions, 7 deletions
diff --git a/gnu/packages/check.scm b/gnu/packages/check.scm
index dc9e93df60b..88afdb2cfce 100644
--- a/gnu/packages/check.scm
+++ b/gnu/packages/check.scm
@@ -2020,22 +2020,35 @@ same arguments.")
(build-system pyproject-build-system)
(arguments
(list
+ ;; tests: 193 passed, 6 skipped, 3 deselected, 10 xfailed
#:test-flags
- ;; Failes with execnet.gateway_base.RemoteError: Traceback (most recent
- ;; call last).
- #~(list "-k" "not test_ignore_sys_path_hook_entry")))
+ ;; See: <https://github.com/pytest-dev/pytest-xdist/issues/1295>.
+ #~(list #$@(map (lambda (ls)
+ (string-append "--deselect=testing/"
+ (string-join ls "::")))
+ ;; execnet.gateway_base.RemoteError: Traceback (most
+ ;; recent call last):
+ '(("test_looponfail.py"
+ "TestRemoteControl"
+ "test_ignore_sys_path_hook_entry")
+ ;; Failed: matched: '*HOOK: pytest_handlecrashitem'
+ ("test_newhooks.py"
+ "TestCrashItem"
+ "test_handlecrashitem_one")
+ ;; Failed: nomatch: '*usage: *
+ ("test_remote.py"
+ "test_remote_usage_prog"))))))
(native-inputs
(list python-filelock
python-pytest
python-setuptools
- python-setuptools-scm
- python-wheel))
+ python-setuptools-scm))
(propagated-inputs
(list python-execnet))
(home-page "https://github.com/pytest-dev/pytest-xdist")
- (synopsis "Plugin for py.test with distributed testing and loop-on-failing modes")
+ (synopsis "Pytest plugin for distributed testing and loop-on-failures testing modes")
(description
- "The pytest-xdist plugin extends py.test with some unique test execution
+ "The pytest-xdist plugin extends pytest with some unique test execution
modes: parallelization, running tests in boxed subprocesses, the ability to
run tests repeatedly when failed, and the ability to run tests on multiple
Python interpreters or platforms. It uses rsync to copy the existing program